<?php

namespace AustraliaPost\Extensions\Business\Endpoints\Errors;


class Errors_Factory {

	/**
	 * @param $error
	 * @return Error
	 */
	public static function make($error)
	{

		if (isset($error['error_code']) && $error['error_code'] === 'API_001') {
			return new System_Error($error);
		}

		if (!isset($error['code'])) {
			return new Generic_Error($error);
		}

		switch ($error['code']) {
			case 400:
				return new Address_Error($error);
			case 401:
				return new Authentication_Error($error);
			case 42001:
				return new No_Products_Found_Warning($error);
			case 42006:
				return new Max_Width_Error($error);
			case 42008:
				return new Max_Length_Error($error);
			case 42009:
				return new Max_Volume_Error($error);
			case 42011:
				return  new Two_Dimensions_Less_Than_5cm_Error($error);
			case 42026:
				return new Max_Weight_Error($error);
			case 51006:
				return new Shipment_Not_Paid_Error($error);
			case 51010:
				return new Label_Expired_Error($error);
		}

		if (isset($error['message'])) {
			return new Generic_Error(['message' => $error['message']]);
		}

		return new Generic_Error([]);
	}

}
